/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.model.doc;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

import org.apache.commons.lang.StringUtils;

@Retention(RetentionPolicy.RUNTIME)
public @interface Link
{

    String href();

    String rel();

    String title();

    boolean required();

    String message() default "Link is missing";

    static class Validator implements ConstraintValidator<Link, String>
    {
        Link link;

        @Override
        public boolean isValid(final String value, final ConstraintValidatorContext context)
        {
            if (!link.required() && StringUtils.isEmpty(value))
            {
                return true;
            }
            else
            {
                context.disableDefaultConstraintViolation();
                context.buildConstraintViolationWithTemplate(link.message())
                    .addConstraintViolation();
            }

            return false;
        }

        @Override
        public void initialize(final Link constraintAnnotation)
        {
            this.link = constraintAnnotation;
        }
    }

}
