/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.model.enumerator;

import java.util.Comparator;

import com.abiquo.model.rest.RESTLink;

public enum LinkOrder implements Comparator<RESTLink>
{
    BY_REL
    {
        @Override
        public int compare(final RESTLink link0, final RESTLink link1)
        {
            if (link0.getRel() == null || link1.getRel() == null)
            {
                return 0;
            }

            return String.CASE_INSENSITIVE_ORDER.compare(link0.getRel(), link1.getRel());
        }
    },

    BY_TITLE
    {
        @Override
        public int compare(final RESTLink link0, final RESTLink link1)
        {
            if (link0.getTitle() == null || link1.getTitle() == null)
            {
                return 0;
            }

            return String.CASE_INSENSITIVE_ORDER.compare(link0.getTitle(), link1.getTitle());
        }
    }
}
