/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.model.transport;

import java.io.Serializable;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.rest.RESTLink;

/**
 * This Entity is the response of 202. It is a list of links (most of the cases one) and an optional
 * Object (most of the cases the string with the message to response).
 * 
 * @author ssedano
 */
@XmlRootElement(name = "acceptedrequest")
public class AcceptedRequestDto<T> extends SingleResourceTransportDto implements Serializable
{
    private static final long serialVersionUID = -7743440222172054557L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.acceptedrequest+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private static final String STATUS_REL = "status";

    private T entity;

    @XmlElement(name = "message", namespace = "", nillable = true, required = false)
    public T getEntity()
    {
        return entity;
    }

    public void setEntity(final T entity)
    {
        this.entity = entity;
    }

    public void setStatusUrlLink(final String url)
    {
        addLink(new RESTLink(STATUS_REL, url));
    }

    public RESTLink getStatusLink()
    {
        return searchLink(STATUS_REL);
    }

    @Override
    public String getMediaType()
    {
        return AcceptedRequestDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
