/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.model.transport;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;

import com.abiquo.model.rest.RESTLink;

public abstract class SingleResourceTransportDto implements Serializable
{
    public static final String API_VERSION = "2.3";

    public static final String API_VERSION_22 = "2.2";

    public static final String API_VERSION_20 = "2.0";

    public static final String APPLICATION = "application";

    private static final long serialVersionUID = 1L;

    protected RESTLink editLink;

    protected List<RESTLink> links;

    @XmlElement(name = "link")
    public List<RESTLink> getLinks()
    {
        if (links == null)
        {
            links = new ArrayList<RESTLink>();
        }
        return links;
    }

    public void setLinks(final List<RESTLink> links)
    {
        this.links = links;
    }

    public void addLink(final RESTLink link)
    {
        if (this.links == null)
        {
            this.links = new ArrayList<RESTLink>();
        }
        this.links.add(link);
    }

    public void addLinks(final List<RESTLink> links)
    {
        if (this.links == null)
        {
            this.links = new ArrayList<RESTLink>();
        }
        this.links.addAll(links);
    }

    public RESTLink getEditLink()
    {
        if (editLink == null)
        {
            editLink = searchLink("edit");
        }
        return editLink;
    }

    public void addEditLink(final RESTLink edit)
    {
        editLink = edit;
        RESTLink currentEdit = searchLink("edit");
        if (currentEdit != null)
        {
            links.remove(currentEdit);
        }
        links.add(editLink);
    }

    public RESTLink searchLink(final String rel)
    {
        if (getLinks() == null)
        {
            setLinks(new ArrayList<RESTLink>());
        }

        for (RESTLink link : getLinks())
        {
            if (link.getRel() != null)
            {
                if (link.getRel().equals(rel))
                {
                    return link;
                }
            }
        }
        return null;
    }

    public List<RESTLink> searchLinks(final String rel)
    {
        List<RESTLink> links = new ArrayList<RESTLink>();

        if (getLinks() == null)
        {
            setLinks(new ArrayList<RESTLink>());
        }

        for (RESTLink link : getLinks())
        {
            if (link.getRel() != null)
            {
                if (link.getRel().equals(rel))
                {
                    links.add(link);
                }
            }
        }
        return links;
    }

    public RESTLink searchLink(final String rel, final String title)
    {
        if (getLinks() == null)
        {
            setLinks(new ArrayList<RESTLink>());
        }

        for (RESTLink link : getLinks())
        {
            if (link.getRel().equals(rel) && link.getTitle().equals(title))
            {
                return link;
            }
        }
        return null;
    }

    public RESTLink searchLinkByHref(final String href)
    {
        if (getLinks() == null)
        {
            setLinks(new ArrayList<RESTLink>());
        }

        for (RESTLink link : getLinks())
        {
            if (link.getHref().equals(href))
            {
                return link;
            }
        }
        return null;
    }

    public void modifyLink(final String rel, final String href)
    {
        searchLink(rel).setHref(href);
    }

    public Integer getIdFromLink(final String rel)
    {
        RESTLink restLink = this.searchLink(rel);
        if (restLink == null)
        {
            return null;
        }
        String href = restLink.getHref();
        // Maybe URIs don't have a trailing slash
        String id =
            href.substring(href.lastIndexOf("/") + 1,
                href.endsWith("/") ? href.length() - 1 : href.length());
        return Integer.valueOf(id);
    }

    public abstract String getMediaType();

    public abstract String getBaseMediaType();
}
