/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.model.transport;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlElement;

import com.abiquo.model.doc.Desc;

public abstract class SingleResourceWithLimitsDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    private int ramSoftLimitInMb;

    private int ramHardLimitInMb;

    private int cpuCountSoftLimit;

    private int cpuCountHardLimit;

    private long hdSoftLimitInMb;

    private long hdHardLimitInMb;

    private long storageSoft;

    private long storageHard;

    private long vlansSoft;

    private long vlansHard;

    private long publicIpsSoft;

    private long publicIpsHard;

    @XmlElement(name = "ramSoft")
    @NotNull
    @Desc("Total amount of RAM memory that may be used by Virtual Machines. Soft limit")
    public int getRamSoftLimitInMb()
    {
        return ramSoftLimitInMb;
    }

    public void setRamSoftLimitInMb(final int ramSoftLimitInMb)
    {
        this.ramSoftLimitInMb = ramSoftLimitInMb;
    }

    @XmlElement(name = "ramHard")
    @NotNull
    @Desc("Total amount of RAM memory that may be used by Virtual Machines. Hard limit")
    public int getRamHardLimitInMb()
    {
        return ramHardLimitInMb;
    }

    public void setRamHardLimitInMb(final int ramHardLimitInMb)
    {
        this.ramHardLimitInMb = ramHardLimitInMb;
    }

    @XmlElement(name = "cpuSoft")
    @NotNull
    @Desc("Total amount of Virtual CPUs that may be used by Virtual Machines. Soft limit")
    public int getCpuCountSoftLimit()
    {
        return cpuCountSoftLimit;
    }

    public void setCpuCountSoftLimit(final int cpuCountSoftLimit)
    {
        this.cpuCountSoftLimit = cpuCountSoftLimit;
    }

    @XmlElement(name = "cpuHard")
    @NotNull
    @Desc("Total amount of Virtual CPUs that may be used by Virtual Machines. Hard limit")
    public int getCpuCountHardLimit()
    {
        return cpuCountHardLimit;
    }

    public void setCpuCountHardLimit(final int cpuCountHardLimit)
    {
        this.cpuCountHardLimit = cpuCountHardLimit;
    }

    @XmlElement(name = "hdSoft")
    @NotNull
    @Desc("Total size of Hard Disks that may be used by Virtual Machines. Soft limit")
    public long getHdSoftLimitInMb()
    {
        return hdSoftLimitInMb;
    }

    public void setHdSoftLimitInMb(final long hdSoftLimitInMb)
    {
        this.hdSoftLimitInMb = hdSoftLimitInMb;
    }

    @XmlElement(name = "hdHard")
    @NotNull
    @Desc("Total size of Hard Disks that may be used by Virtual Machines. Hard limit")
    public long getHdHardLimitInMb()
    {
        return hdHardLimitInMb;
    }

    public void setHdHardLimitInMb(final long hdHardLimitInMb)
    {
        this.hdHardLimitInMb = hdHardLimitInMb;
    }

    @NotNull
    @Desc("Total size of external storage that may be assigned. Soft limit")
    public long getStorageSoft()
    {
        return storageSoft;
    }

    public void setStorageSoft(final long storageSoft)
    {
        this.storageSoft = storageSoft;
    }

    @NotNull
    @Desc("Total size of external storage that may be assigned. Hard limit")
    public long getStorageHard()
    {
        return storageHard;
    }

    public void setStorageHard(final long storageHard)
    {
        this.storageHard = storageHard;
    }

    @NotNull
    @Desc("Total amount of VLANs that may be defined. Soft limit")
    public long getVlansSoft()
    {
        return vlansSoft;
    }

    public void setVlansSoft(final long vlansSoft)
    {
        this.vlansSoft = vlansSoft;
    }

    @NotNull
    @Desc("Total amount of VLANs that may be defined. Hard limit")
    public long getVlansHard()
    {
        return vlansHard;
    }

    public void setVlansHard(final long vlansHard)
    {
        this.vlansHard = vlansHard;
    }

    @NotNull
    @Desc("Total amount of Public IPs that may be defined. Soft limit")
    public long getPublicIpsSoft()
    {
        return publicIpsSoft;
    }

    public void setPublicIpsSoft(final long publicIpsSoft)
    {
        this.publicIpsSoft = publicIpsSoft;
    }

    @NotNull
    @Desc("Total amount of Public IPs that may be defined. Hard limit")
    public long getPublicIpsHard()
    {
        return publicIpsHard;
    }

    public void setPublicIpsHard(final long publicIpsHard)
    {
        this.publicIpsHard = publicIpsHard;
    }

    public void setStorageLimits(final long softLimit, final long hardLimit)
    {
        setStorageSoft(softLimit);
        setStorageHard(hardLimit);
    }

    public void setVlansLimits(final long softLimit, final long hardLimit)
    {
        setVlansSoft(softLimit);
        setVlansHard(hardLimit);
    }

    public void setPublicIPLimits(final long softLimit, final long hardLimit)
    {
        setPublicIpsSoft(softLimit);
        setPublicIpsHard(hardLimit);
    }

    public void setRamLimitsInMb(final int softLimit, final int hardLimit)
    {
        setRamSoftLimitInMb(softLimit);
        setRamHardLimitInMb(hardLimit);
    }

    public void setCpuCountLimits(final int softLimit, final int hardLimit)
    {
        setCpuCountSoftLimit(softLimit);
        setCpuCountHardLimit(hardLimit);
    }

    public void setHdLimitsInMb(final long softLimit, final long hardLimit)
    {
        setHdSoftLimitInMb(softLimit);
        setHdHardLimitInMb(hardLimit);
    }
}
