/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.appslibrary;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "datacenterRepository")
public class DatacenterRepositoryDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 6344939071248048966L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.datacenterrepository+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private String name;

    private String error;

    private String repositoryLocation;

    private long repositoryRemainingMb;

    private long repositoryCapacityMb;

    @NotNull
    @Desc(value = "Name of the VLAN")
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    @Desc(value = "Returns if there is any error in repository")
    public String getError()
    {
        return error;
    }

    public void setError(final String error)
    {
        this.error = error;
    }

    @Desc(value = "Returns the repository location")
    public String getRepositoryLocation()
    {
        return repositoryLocation;
    }

    public void setRepositoryLocation(final String repositoryLocation)
    {
        this.repositoryLocation = repositoryLocation;
    }

    @Desc(value = "Returns the remaining capacity in the repository")
    public long getRepositoryRemainingMb()
    {
        return repositoryRemainingMb;
    }

    public void setRepositoryRemainingMb(final long repositoryRemainingMb)
    {
        this.repositoryRemainingMb = repositoryRemainingMb;
    }

    @Desc(value = "The capacity of repository in Mb")
    public long getRepositoryCapacityMb()
    {
        return repositoryCapacityMb;
    }

    public void setRepositoryCapacityMb(final long repositoryCapacityMb)
    {
        this.repositoryCapacityMb = repositoryCapacityMb;
    }

    @Override
    public String getMediaType()
    {
        return DatacenterRepositoryDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
