/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.appslibrary;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.commons.lang.StringUtils;
import com.abiquo.model.doc.Desc;
import com.abiquo.model.enumerator.EthernetDriverType;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "templateDefinition")
public class TemplateDefinitionDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = -2655629613600887997L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.templatedefinition+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    private String url;

    private String name;

    private String description;

    private String productName;

    private String productVendor;

    private String productUrl;

    private String productVersion;

    private String diskFormatType;

    private long diskFileSize;

    private String iconUrl;

    private EthernetDriverType ethernetDriverType;

    @Desc("Identifier of the template definition")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    @Desc("The product version of the template definition")
    public String getProductVersion()
    {
        return productVersion;
    }

    public void setProductVersion(final String productVersion)
    {
        this.productVersion = productVersion;
    }

    @Desc("Name of the template definition")
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = StringUtils.strip(name);
    }

    @Desc("The template definition vendor")
    public String getProductVendor()
    {
        return productVendor;
    }

    public void setProductVendor(final String productVendor)
    {
        this.productVendor = StringUtils.strip(productVendor);
    }

    @Desc("The product vendor url of the template definition")
    public String getProductUrl()
    {
        return productUrl;
    }

    public void setProductUrl(final String productUrl)
    {
        this.productUrl = productUrl;
    }

    @NotNull
    @Desc("The url of the template definition")
    public String getUrl()
    {
        return url;
    }

    public void setUrl(final String url)
    {
        this.url = url;
    }

    @Desc("The format type of the disk for the template definition")
    public String getDiskFormatType()
    {
        return diskFormatType;
    }

    public void setDiskFormatType(final String type)
    {
        this.diskFormatType = type;
    }

    @Desc("The product name of the product")
    public String getProductName()
    {
        return productName;
    }

    public void setProductName(final String productName)
    {
        this.productName = StringUtils.strip(productName);
    }

    @NotNull
    @Desc("The Disk file size in Mb")
    public long getDiskFileSize()
    {
        return diskFileSize;
    }

    public void setDiskFileSize(final long diskFileSize)
    {
        this.diskFileSize = diskFileSize;
    }

    @NotNull
    @Desc("The description of the template definition")
    public String getDescription()
    {
        return description;
    }

    public void setDescription(final String description)
    {
        this.description = StringUtils.strip(description);
    }

    @Override
    public String getMediaType()
    {
        return TemplateDefinitionDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    public void setIconUrl(final String iconUrl)
    {
        this.iconUrl = iconUrl;
    }

    public String getIconUrl()
    {
        return iconUrl;
    }

    public EthernetDriverType getEthernetDriverType()
    {
        return ethernetDriverType;
    }

    public void setEthernetDriverType(final EthernetDriverType ethernetDriverType)
    {
        this.ethernetDriverType = ethernetDriverType;
    }
}
