/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.appslibrary;

import java.util.Date;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.enumerator.VMTemplateState;
import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "virtualMachineTemplate")
@XmlType(propOrder = {"id", "name", "description", "path", "diskFormatType", "diskFileSize",
"cpuRequired", "ramRequired", "hdRequired", "shared", "state", "costCode", "creationDate",
"creationUser", "chefEnabled", "iconUrl"})
public class VirtualMachineTemplateDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE =
        "application/vnd.abiquo.virtualmachinetemplate+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    private String diskFormatType;

    private String name;

    private int cpuRequired;

    private String path;

    private int ramRequired;

    private long hdRequired;

    private long diskFileSize;

    private String description;

    private boolean shared;

    private VMTemplateState state;

    private int costCode;

    private Date creationDate;

    private String creationUser;

    private boolean chefEnabled;

    private String iconUrl;

    public boolean isChefEnabled()
    {
        return chefEnabled;
    }

    public void setChefEnabled(final boolean chefEnabled)
    {
        this.chefEnabled = chefEnabled;
    }

    @Desc("Identifier of the virtual machine template definition")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    @NotNull
    @Desc("Disk Format type of the virtual machine template definition")
    public String getDiskFormatType()
    {
        return diskFormatType;
    }

    public void setDiskFormatType(final String diskFormatType)
    {
        this.diskFormatType = diskFormatType;
    }

    @NotNull
    @Desc("Name of the virtual machine template definition")
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    @Desc("The number of CPU required")
    public int getCpuRequired()
    {
        return cpuRequired;
    }

    public void setCpuRequired(final int cpuRequired)
    {
        this.cpuRequired = cpuRequired;
    }

    @NotNull
    @Desc("Path of the virtual machine template definition")
    public String getPath()
    {
        return path;
    }

    public void setPath(final String path)
    {
        this.path = path;
    }

    @Desc("The Ram required for the virtual machine template definition")
    public int getRamRequired()
    {
        return ramRequired;
    }

    public void setRamRequired(final int ramRequired)
    {
        this.ramRequired = ramRequired;
    }

    @Desc("the HD required for the virtual mahcine template definition")
    public long getHdRequired()
    {
        return hdRequired;
    }

    public void setHdRequired(final long hdRequired)
    {
        this.hdRequired = hdRequired;
    }

    @NotNull
    @Desc("The disk file size of the virtual mahcine template definition ")
    public long getDiskFileSize()
    {
        return diskFileSize;
    }

    public void setDiskFileSize(final long diskFileSize)
    {
        this.diskFileSize = diskFileSize;
    }

    @Desc("Description of the virtual machine template definition")
    public String getDescription()
    {
        return description;
    }

    public void setDescription(final String description)
    {
        this.description = description;
    }

    @NotNull
    @Desc("Returns if the current virtual machine template definition is shared")
    public boolean isShared()
    {
        return shared;
    }

    public void setShared(final boolean shared)
    {
        this.shared = shared;
    }

    @Desc("Returns the state of the virtual machine template")
    public VMTemplateState getState()
    {
        return state;
    }

    public void setState(final VMTemplateState state)
    {
        this.state = state;
    }

    @Desc("The cost code of the virtual machine template")
    public int getCostCode()
    {
        return costCode;
    }

    public void setCostCode(final int costCode)
    {
        this.costCode = costCode;
    }

    @Desc("The creation date of the virtual machine template")
    public Date getCreationDate()
    {
        return creationDate;
    }

    public void setCreationDate(final Date creationDate)
    {
        this.creationDate = creationDate;
    }

    @Desc("The user who created the virtual machine template")
    public String getCreationUser()
    {
        return creationUser;
    }

    public void setCreationUser(final String creationUser)
    {
        this.creationUser = creationUser;
    }

    @Override
    public String getMediaType()
    {
        return VirtualMachineTemplateDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    public void setIconUrl(final String iconUrl)
    {
        this.iconUrl = iconUrl;
    }

    @Desc("The URI of the icon of the virtual machine template")
    public String getIconUrl()
    {
        return iconUrl;
    }

}
