/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.appslibrary;

import java.io.Serializable;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * DTO for persistent parameters of the virtual machine templates.
 * <p>
 * parameters:
 * <li>persistentTemplateName is required</li>
 * <li>persistentTemplateVolume is not required, if is null will be used the value of
 * persistentTemplateName and if the storage link is a volume link will be omitted</li>
 * <li>link of the virtual machine template</li>
 * <li>link of the virtual datacenter</li>
 * <li>link of the storage (volume or tier)</li>
 * 
 * @author Sergi Castro
 */
@XmlRootElement(name = "virtualmachinetemplatepersistent")
public class VirtualMachineTemplatePersistentDto extends SingleResourceTransportDto implements
    Serializable
{
    private static final long serialVersionUID = -1458892631967828227L;

    public static final String BASE_MEDIA_TYPE =
        "application/vnd.abiquo.virtualmachinetemplatepersistent+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    protected String persistentTemplateName;

    protected String persistentVolumeName;

    public String getPersistentTemplateName()
    {
        return persistentTemplateName;
    }

    public void setPersistentTemplateName(final String persistentTemplateName)
    {
        this.persistentTemplateName = persistentTemplateName;
    }

    public String getPersistentVolumeName()
    {
        return persistentVolumeName;
    }

    public void setPersistentVolumeName(final String persistentVolumeName)
    {
        this.persistentVolumeName = persistentVolumeName;
    }

    @Override
    public String getMediaType()
    {
        return VirtualMachineTemplatePersistentDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
