/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.enumerator.DiskFormatType;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "hypervisortype")
public class HypervisorTypeDto extends SingleResourceTransportDto
{

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.hypervisortype+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private static final long serialVersionUID = -6899075534020087650L;

    private int defaultPort;

    private DiskFormatType baseFormat;

    private DiskFormatType[] compatibilityTable;

    private Integer id;

    private String name;

    private String realName;

    @Desc("Opaque ID of the hypervisor type")
    @Output
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer Id)
    {
        id = Id;
    }

    @Desc("Base format of the hypervisor type")
    @NotNull
    public DiskFormatType getBaseFormat()
    {
        return baseFormat;
    }

    public void setBaseFormat(final DiskFormatType baseFormat)
    {
        this.baseFormat = baseFormat;
    }

    @Desc("Compatibility of the hypervisor type")
    public DiskFormatType[] getCompatibilityTable()
    {
        return compatibilityTable;
    }

    public void setCompatibilityTable(final DiskFormatType[] compatibilityTable)
    {
        this.compatibilityTable = compatibilityTable;
    }

    @Desc("Default port of the hypervisor type")
    @NotNull
    public int getDefaultPort()
    {
        return defaultPort;
    }

    public void setDefaultPort(final int defaultPort)
    {
        this.defaultPort = defaultPort;
    }

    @Desc("Name of the hypervisor type")
    @NotNull
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    @Desc("Friendly name of the hypervisor type")
    @NotNull
    public String getRealName()
    {
        return realName;
    }

    public void setRealName(final String realName)
    {
        this.realName = realName;
    }

    @Override
    public String getMediaType()
    {
        return HypervisorTypeDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
