/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;
import com.abiquo.server.core.task.TasksDto;

@XmlRootElement(name = "virtualAppliance")
public class VirtualApplianceDto extends SingleResourceTransportDto
{
    public static final String COPY_VIRTUAL_APPLIANCE_MIME_TYPE =
        "application/vnd.cp-virtualappliance+xml";

    public static final String MOVE_VIRTUAL_APPLIANCE_MIME_TYPE =
        "application/vnd.mv-virtualappliance+xml";

    /**
     * 
     */
    private static final long serialVersionUID = 6614050007994524638L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.virtualappliance+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    @Desc("Opaque ID of the virtual appliance")
    @Output
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private String name;

    @Desc("Name of the virtual appliance")
    @NotNull
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    private String nodeconnections;

    @Desc("Logical connections made through the Abiquo flex client")
    public String getNodeconnections()
    {
        return nodeconnections;
    }

    public void setNodeconnections(final String nodeconnections)
    {
        this.nodeconnections = nodeconnections;
    }

    private int publicApp;

    @Desc("Deprecated")
    public int getPublicApp()
    {
        return publicApp;
    }

    public void setPublicApp(final int publicApp)
    {
        this.publicApp = publicApp;
    }

    private int highDisponibility;

    @Desc("Deprecated")
    public int getHighDisponibility()
    {
        return highDisponibility;
    }

    public void setHighDisponibility(final int highDisponibility)
    {
        this.highDisponibility = highDisponibility;
    }

    private int error;

    @Desc("Was there an error on the last operation on any of its nodes?")
    @Output
    public int getError()
    {
        return error;
    }

    public void setError(final int error)
    {
        this.error = error;
    }

    private VirtualApplianceState subState;

    @Desc("Deprecated")
    public VirtualApplianceState getSubState()
    {
        return subState;
    }

    public void setSubState(final VirtualApplianceState subState)
    {
        this.subState = subState;
    }

    private VirtualApplianceState state;

    @Desc("Current state. Inferred from its virtual machines")
    @Output
    public VirtualApplianceState getState()
    {
        return state;
    }

    public void setState(final VirtualApplianceState state)
    {
        this.state = state;
    }

    @Override
    public String getMediaType()
    {
        return VirtualApplianceDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    /**
     * TODO This should be abstracted
     */
    private TasksDto lastTasks;

    @Desc("Last task of every virtual machine")
    @Output
    public TasksDto getLastTasks()
    {
        return lastTasks;
    }

    public void setLastTasks(final TasksDto lastTasks)
    {
        this.lastTasks = lastTasks;
    }

}
