/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import java.math.BigDecimal;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "virtualAppliancePrice")
public class VirtualAppliancePriceDto extends SingleResourceTransportDto
{

    /**
     * 
     */
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.virtualapplianceprice+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public VirtualAppliancePriceDto()
    {
    }

    public VirtualAppliancePriceDto(final BigDecimal costCodeCost, final BigDecimal computeCost,
        final BigDecimal networkCost, final BigDecimal storageCost,
        final BigDecimal additionalVolumCost, final BigDecimal totalCost)
    {
        super();
        this.costCodeCost = costCodeCost;
        this.computeCost = computeCost;
        this.networkCost = networkCost;
        this.storageCost = storageCost;
        this.additionalVolumCost = additionalVolumCost;
        this.totalCost = totalCost;
    }

    /** Value for the image being deployed */
    private BigDecimal costCodeCost;

    /** Value for the CPU, memory */
    private BigDecimal computeCost;

    /** Value for public IPs */
    private BigDecimal networkCost;

    /** Value for the datastore */
    private BigDecimal storageCost;

    /** Value for the volume */
    private BigDecimal additionalVolumCost;

    /** Value for deploy */
    private BigDecimal standingCharge;

    /** Value total */
    private BigDecimal totalCost;

    private Integer minimumCharge;

    private BigDecimal minimumChargePeriod;

    @Desc("Value for miniumum charge period")
    @NotNull
    public BigDecimal getMinimumChargePeriod()
    {
        return minimumChargePeriod;
    }

    public void setMinimumChargePeriod(final BigDecimal minimumChargePeriod)
    {
        this.minimumChargePeriod = minimumChargePeriod;
    }

    @Desc("Minimum Charge")
    @NotNull
    public Integer getMinimumCharge()
    {
        return minimumCharge;
    }

    public void setMinimumCharge(final Integer minimumCharge)
    {
        this.minimumCharge = minimumCharge;
    }

    @Desc("Value for the image being deployed")
    @NotNull
    public BigDecimal getCostCodeCost()
    {
        return costCodeCost;
    }

    public void setCostCodeCost(final BigDecimal costCodeCost)
    {
        this.costCodeCost = costCodeCost;
    }

    @Desc("Value for the CPU, memory")
    @NotNull
    public BigDecimal getComputeCost()
    {
        return computeCost;
    }

    public void setComputeCost(final BigDecimal computeCost)
    {
        this.computeCost = computeCost;
    }

    @Desc("Value for public IPs")
    @NotNull
    public BigDecimal getNetworkCost()
    {
        return networkCost;
    }

    public void setNetworkCost(final BigDecimal networkCost)
    {
        this.networkCost = networkCost;
    }

    @Desc("Value for the datastore")
    @NotNull
    public BigDecimal getStorageCost()
    {
        return storageCost;
    }

    public void setStorageCost(final BigDecimal storageCost)
    {
        this.storageCost = storageCost;
    }

    @Desc("Value for the volume")
    @NotNull
    public BigDecimal getAdditionalVolumCost()
    {
        return additionalVolumCost;
    }

    public void setAdditionalVolumCost(final BigDecimal additionalVolumCost)
    {
        this.additionalVolumCost = additionalVolumCost;
    }

    @Desc("Value for deploy")
    @NotNull
    public BigDecimal getStandingCharge()
    {
        return standingCharge;
    }

    public void setStandingCharge(final BigDecimal standingCharge)
    {
        this.standingCharge = standingCharge;
    }

    @Desc("Value total")
    @NotNull
    public BigDecimal getTotalCost()
    {
        return totalCost;
    }

    public void setTotalCost(final BigDecimal totalCost)
    {
        this.totalCost = totalCost;
    }

    @Override
    public String getMediaType()
    {
        return VirtualAppliancePriceDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
