/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.enumerator.HypervisorType;
import com.abiquo.model.transport.SingleResourceWithLimitsDto;
import com.abiquo.server.core.infrastructure.network.VLANNetworkDto;

@XmlRootElement(name = "virtualDatacenter")
public class VirtualDatacenterDto extends SingleResourceWithLimitsDto
{
    /**
     * 
     */
    private static final long serialVersionUID = -2165018992377526633L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.virtualdatacenter+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public static final String MEDIA_TYPE_20 = BASE_MEDIA_TYPE + "; version=" + API_VERSION_20;

    private Integer id;

    private String name;

    private HypervisorType hypervisorType;

    private VLANNetworkDto vlan;

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    @Desc("Hypervisor type of the virtual datacenter")
    @NotNull
    public HypervisorType getHypervisorType()
    {
        return hypervisorType;
    }

    @Desc("Opaque ID of the virtual datacenter")
    @Output
    public Integer getId()
    {
        return id;
    }

    @Override
    public String getMediaType()
    {
        return VirtualDatacenterDto.MEDIA_TYPE;
    }

    @Desc("Virtual datacenter's name")
    @NotNull
    public String getName()
    {
        return name;
    }

    @Desc("Virtual datacenter network")
    @NotNull
    @XmlElement(name = "network")
    public VLANNetworkDto getVlan()
    {
        return vlan;
    }

    public void setHypervisorType(final HypervisorType hypervisorType)
    {
        this.hypervisorType = hypervisorType;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    public void setVlan(final VLANNetworkDto vlan)
    {
        this.vlan = vlan;
    }
}
