/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import java.io.Serializable;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * DTO for instance parameters of the virtual machine.
 * 
 * @author eruiz@abiquo.com
 */
@XmlRootElement(name = "virtualmachineinstance")
public class VirtualMachineInstanceDto extends SingleResourceTransportDto implements Serializable
{
    private static final long serialVersionUID = -372239566628574960L;

    public static final String BASE_MEDIA_TYPE =
        "application/vnd.abiquo.virtualmachineinstance+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    protected String instanceName;

    @Desc("Instance name")
    @NotNull
    public String getInstanceName()
    {
        return instanceName;
    }

    public void setInstanceName(String snapshotName)
    {
        this.instanceName = snapshotName;
    }

    @Override
    public String getMediaType()
    {
        return VirtualMachineInstanceDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
