/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud.chef;

import java.io.Serializable;
import java.util.LinkedList;
import java.util.List;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "bootstrap")
@XmlType(propOrder = {"nodeName", "chefConfig"})
public class BootstrapDto extends SingleResourceTransportDto implements Serializable
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.extended-bootstrap+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version="
        + SingleResourceTransportDto.API_VERSION;

    private static final long serialVersionUID = 1L;

    private String nodeName;

    private ChefBootstrap chefConfig;

    @Desc("Name of the chef node")
    @NotNull
    @XmlElement(name = "node")
    public String getNodeName()
    {
        return nodeName;
    }

    public void setNodeName(final String nodeName)
    {
        this.nodeName = nodeName;
    }

    @Desc("Chef configuration")
    @NotNull
    @XmlElement(name = "chef")
    public ChefBootstrap getChefConfig()
    {
        return chefConfig;
    }

    public void setChefConfig(final ChefBootstrap chefConfig)
    {
        this.chefConfig = chefConfig;
    }

    @XmlRootElement(name = "chef")
    @XmlType(propOrder = {"chefServerURL", "validatorName", "validationCertificate", "runlist"})
    public static class ChefBootstrap implements Serializable
    {
        private static final long serialVersionUID = 1L;

        private String chefServerURL;

        private String validatorName;

        private String validationCertificate;

        private RunlistDto runlist = new RunlistDto();

        @Desc("URL of the Chef server")
        @NotNull
        @XmlElement(name = "chef-server-url")
        public String getChefServerURL()
        {
            return chefServerURL;
        }

        public void setChefServerURL(final String chefServerURL)
        {
            this.chefServerURL = chefServerURL;
        }

        @Desc("Validation of the Chef client name")
        @NotNull
        @XmlElement(name = "validation-client-name")
        public String getValidatorName()
        {
            return validatorName;
        }

        public void setValidatorName(final String validatorName)
        {
            this.validatorName = validatorName;
        }

        @Desc("Chef validation certificate")
        @NotNull
        @XmlElement(name = "validation-cert")
        public String getValidationCertificate()
        {
            return validationCertificate;
        }

        public void setValidationCertificate(final String validationCertificate)
        {
            this.validationCertificate = validationCertificate;
        }

        @Desc("Chef list of items to run")
        @NotNull
        public RunlistDto getRunlist()
        {
            return runlist;
        }

        public void setRunlist(final RunlistDto runlist)
        {
            this.runlist = runlist;
        }

        @XmlRootElement(name = "runlist")
        public static class RunlistDto implements Serializable
        {
            private static final long serialVersionUID = 1L;

            private List<String> elements = new LinkedList<String>();

            public void add(final String element)
            {
                elements.add(element);
            }

            public int size()
            {
                return elements.size();
            }

            @XmlElement(name = "element")
            public List<String> getElements()
            {
                return elements;
            }

            public void setElements(final List<String> elements)
            {
                this.elements = elements;
            }
        }
    }

    @Override
    public String getMediaType()
    {
        return MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
