/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.enterprise;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "roleLdap")
public class RoleLdapDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;
    
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.roleldap+xml";
    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;
    
    public RoleLdapDto()
    {
        super();
    }

    public RoleLdapDto(final Integer id, final String roleLdap)
    {
        super();
        this.id = id;
        this.roleLdap = roleLdap;
    }

    private Integer id;

    @Output
    @Desc("Identifier for LDAP Group")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private String roleLdap;

    @NotNull
    @Desc("The LDAP group that the user belongs to. Required in LDAP mode")
    public String getRoleLdap()
    {
        return roleLdap;
    }

    public void setRoleLdap(final String roleLdap)
    {
        this.roleLdap = roleLdap;
    }

    @Override
    public String getMediaType()
    {
        return RoleLdapDto.MEDIA_TYPE;
    }
    
    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
