/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.enterprise;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;

@XmlRootElement(name = "roleWithLdap")
public class RoleWithLdapDto extends RoleDto
{
    private static final long serialVersionUID = 1L;
    
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.rolewithldap+xml";
    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;
    
    public RoleWithLdapDto()
    {
    }

    public RoleWithLdapDto(final RoleDto dto)
    {
        super();
        this.setBlocked(dto.isBlocked());
        this.setId(dto.getId());
        this.setIdEnterprise(dto.getIdEnterprise());
        this.setName(dto.getName());
        this.setLinks(dto.getLinks());
    }

    private Integer idLdap;

    @Override
    public String getLdap()
    {
        return ldap;
    }

    @Override
    public void setLdap(final String ldap)
    {
        this.ldap = ldap;
    }

    @Output
    @Desc("Identifier for LDAP group")
    public Integer getIdLdap()
    {
        return idLdap;
    }

    public void setIdLdap(final Integer idLdap)
    {
        this.idLdap = idLdap;
    }

    public RoleDto toRoleDto()
    {
        RoleDto dto = new RoleDto();
        dto.setId(this.getId());
        dto.setName(this.getName());
        dto.setBlocked(this.isBlocked());
        dto.setIdEnterprise(this.getIdEnterprise());
        dto.setLinks(this.getLinks());
        return dto;
    }

    @Override
    public String getMediaType()
    {
        return RoleWithLdapDto.MEDIA_TYPE;
    }
    
    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
    
}
