/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.event;

import java.util.Date;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.enumerator.SeverityType;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "event")
public class EventDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = -5357501732062265592L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.event+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private String stacktrace;

    public String getStacktrace()
    {
        return stacktrace;
    }

    public void setStacktrace(final String stacktrace)
    {
        this.stacktrace = stacktrace;
    }

    private String component;

    public String getComponent()
    {
        return component;
    }

    public void setComponent(final String component)
    {
        this.component = component;
    }

    private String performedBy;

    public String getPerformedBy()
    {
        return performedBy;
    }

    public void setPerformedBy(final String performedBy)
    {
        this.performedBy = performedBy;
    }

    private Integer idNetwork;

    public Integer getIdNetwork()
    {
        return idNetwork;
    }

    public void setIdNetwork(final Integer idNetwork)
    {
        this.idNetwork = idNetwork;
    }

    private String idVolume;

    public String getIdVolume()
    {
        return idVolume;
    }

    public void setIdVolume(final String idVolume)
    {
        this.idVolume = idVolume;
    }

    private String storagePool;

    public String getStoragePool()
    {
        return storagePool;
    }

    public void setStoragePool(final String storagePool)
    {
        this.storagePool = storagePool;
    }

    private Date timestamp;

    public Date getTimestamp()
    {
        return timestamp;
    }

    public void setTimestamp(final Date timestamp)
    {
        this.timestamp = timestamp;
    }

    private String virtualApp;

    public String getVirtualApp()
    {
        return virtualApp;
    }

    public void setVirtualApp(final String virtualApp)
    {
        this.virtualApp = virtualApp;
    }

    private String datacenter;

    public String getDatacenter()
    {
        return datacenter;
    }

    public void setDatacenter(final String datacenter)
    {
        this.datacenter = datacenter;
    }

    private String actionPerformed;

    public String getActionPerformed()
    {
        return actionPerformed;
    }

    public void setActionPerformed(final String actionPerformed)
    {
        this.actionPerformed = actionPerformed;
    }

    private Integer idVirtualMachine;

    public Integer getIdVirtualMachine()
    {
        return idVirtualMachine;
    }

    public void setIdVirtualMachine(final Integer idVirtualMachine)
    {
        this.idVirtualMachine = idVirtualMachine;
    }

    private String virtualDatacenter;

    public String getVirtualDatacenter()
    {
        return virtualDatacenter;
    }

    public void setVirtualDatacenter(final String virtualDatacenter)
    {
        this.virtualDatacenter = virtualDatacenter;
    }

    private String enterprise;

    public String getEnterprise()
    {
        return enterprise;
    }

    public void setEnterprise(final String enterprise)
    {
        this.enterprise = enterprise;
    }

    private String storageSystem;

    public String getStorageSystem()
    {
        return storageSystem;
    }

    public void setStorageSystem(final String storageSystem)
    {
        this.storageSystem = storageSystem;
    }

    private Integer idPhysicalMachine;

    public Integer getIdPhysicalMachine()
    {
        return idPhysicalMachine;
    }

    public void setIdPhysicalMachine(final Integer idPhysicalMachine)
    {
        this.idPhysicalMachine = idPhysicalMachine;
    }

    private SeverityType severity;

    public SeverityType getSeverity()
    {
        return severity;
    }

    public void setSeverity(final SeverityType severity)
    {
        this.severity = severity;
    }

    private Integer idStorageSystem;

    public Integer getIdStorageSystem()
    {
        return idStorageSystem;
    }

    public void setIdStorageSystem(final Integer idStorageSystem)
    {
        this.idStorageSystem = idStorageSystem;
    }

    private Integer idDatacenter;

    public Integer getIdDatacenter()
    {
        return idDatacenter;
    }

    public void setIdDatacenter(final Integer idDatacenter)
    {
        this.idDatacenter = idDatacenter;
    }

    private String network;

    public String getNetwork()
    {
        return network;
    }

    public void setNetwork(final String network)
    {
        this.network = network;
    }

    private String physicalMachine;

    public String getPhysicalMachine()
    {
        return physicalMachine;
    }

    public void setPhysicalMachine(final String physicalMachine)
    {
        this.physicalMachine = physicalMachine;
    }

    private String rack;

    public String getRack()
    {
        return rack;
    }

    public void setRack(final String rack)
    {
        this.rack = rack;
    }

    private Integer idVirtualDatacenter;

    public Integer getIdVirtualDatacenter()
    {
        return idVirtualDatacenter;
    }

    public void setIdVirtualDatacenter(final Integer idVirtualDatacenter)
    {
        this.idVirtualDatacenter = idVirtualDatacenter;
    }

    private Integer idSubnet;

    public Integer getIdSubnet()
    {
        return idSubnet;
    }

    public void setIdSubnet(final Integer idSubnet)
    {
        this.idSubnet = idSubnet;
    }

    private String volume;

    public String getVolume()
    {
        return volume;
    }

    public void setVolume(final String volume)
    {
        this.volume = volume;
    }

    private String subnet;

    public String getSubnet()
    {
        return subnet;
    }

    public void setSubnet(final String subnet)
    {
        this.subnet = subnet;
    }

    private Integer idUser;

    public Integer getIdUser()
    {
        return idUser;
    }

    public void setIdUser(final Integer idUser)
    {
        this.idUser = idUser;
    }

    private String idStoragePool;

    public String getIdStoragePool()
    {
        return idStoragePool;
    }

    public void setIdStoragePool(final String idStoragePool)
    {
        this.idStoragePool = idStoragePool;
    }

    private String user;

    public String getUser()
    {
        return user;
    }

    public void setUser(final String user)
    {
        this.user = user;
    }

    private Integer idRack;

    public Integer getIdRack()
    {
        return idRack;
    }

    public void setIdRack(final Integer idRack)
    {
        this.idRack = idRack;
    }

    private String virtualMachine;

    public String getVirtualMachine()
    {
        return virtualMachine;
    }

    public void setVirtualMachine(final String virtualMachine)
    {
        this.virtualMachine = virtualMachine;
    }

    private Integer idVirtualApp;

    public Integer getIdVirtualApp()
    {
        return idVirtualApp;
    }

    public void setIdVirtualApp(final Integer idVirtualApp)
    {
        this.idVirtualApp = idVirtualApp;
    }

    private Integer idEnterprise;

    public Integer getIdEnterprise()
    {
        return idEnterprise;
    }

    public void setIdEnterprise(final Integer idEnterprise)
    {
        this.idEnterprise = idEnterprise;
    }

    @Override
    public String getMediaType()
    {
        return EventDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return EventDto.BASE_MEDIA_TYPE;
    }

}
