/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure;

import java.io.Serializable;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "rack")
public class RackDto extends SingleResourceTransportDto implements Serializable
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.rack+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private static final long serialVersionUID = 1L;

    private Integer id;

    private String name, shortDescription, longDescription;

    private Integer vlanIdMin, vlanIdMax, vlanPerVdcReserved, nrsq;

    private String vlansIdAvoided;

    private boolean haEnabled = false;

    @Desc("Identifier of the entity")
    @Output
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    @Desc("Name of the rack")
    @NotNull
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    @Desc("Short description of the rack")
    public String getShortDescription()
    {
        return shortDescription;
    }

    public void setShortDescription(final String description)
    {
        this.shortDescription = description;
    }

    @Desc("Long description of the rack")
    public String getLongDescription()
    {
        return longDescription;
    }

    public void setLongDescription(final String description)
    {
        this.longDescription = description;
    }

    @Desc("Minimum value of the tag of the VLANs allowed in the rack")
    public Integer getVlanIdMin()
    {
        return vlanIdMin;
    }

    public void setVlanIdMin(final Integer vlanIdMin)
    {
        this.vlanIdMin = vlanIdMin;
    }

    @Desc("Maximum value of the tag of the VLANs allowed in the rack")
    public Integer getVlanIdMax()
    {
        return vlanIdMax;
    }

    public void setVlanIdMax(final Integer vlanIdMax)
    {
        this.vlanIdMax = vlanIdMax;
    }

    @Desc("Specify the percentatge of new virtual datacenters tolerance in allocation")
    public Integer getNrsq()
    {
        return nrsq;
    }

    public void setNrsq(final Integer nrsq)
    {
        this.nrsq = nrsq;
    }

    @Desc("List of tags avoided in the VLANs allowed in the rack")
    public String getVlansIdAvoided()
    {
        return vlansIdAvoided;
    }

    public void setVlansIdAvoided(final String vlansIdAvoided)
    {
        this.vlansIdAvoided = vlansIdAvoided;
    }

    @Desc("Deprecated field.")
    @Output
    public Integer getVlanPerVdcReserved()
    {
        return vlanPerVdcReserved;
    }

    public void setVlanPerVdcReserved(final Integer vlanPerVdcReserved)
    {
        this.vlanPerVdcReserved = vlanPerVdcReserved;
    }

    @Desc("HA enabled in the rack")
    public boolean isHaEnabled()
    {
        return haEnabled;
    }

    public void setHaEnabled(final boolean haEnabled)
    {
        this.haEnabled = haEnabled;
    }

    @Override
    public String getMediaType()
    {
        return RackDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
