/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.WrapperDto;
import com.abiquo.model.transport.error.ErrorsDto;

@XmlRootElement(name = "remoteServices")
public class RemoteServicesDto extends WrapperDto<RemoteServiceDto>
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.remoteservices+xml";
    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;
    /**
     * Default serial version.
     */
    private static final long serialVersionUID = 1L;

    private ErrorsDto configErrors;

    public ErrorsDto getConfigErrors()
    {
        return configErrors;
    }

    public void setConfigErrors(final ErrorsDto configErrors)
    {
        this.configErrors = configErrors;
    }

    @Override
    @XmlElement(name = "remoteService")
    public List<RemoteServiceDto> getCollection()
    {
        if (collection == null)
        {
            collection = new ArrayList<RemoteServiceDto>();
        }
        return collection;
    }
    
    @Override
    public String getMediaType()
    {
        return RemoteServicesDto.MEDIA_TYPE;
    }
    
    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
