/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.WrapperDto;
import com.abiquo.model.transport.error.ErrorsDto;

@XmlRootElement(name = "reservedMachines")
public class ReservedMachinesDto extends WrapperDto<ReservedMachineDto>
{

    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.reservedmachines+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private ErrorsDto errors;

    public ErrorsDto getErrors()
    {
        return errors;
    }

    public void setErrors(final ErrorsDto errors)
    {
        this.errors = errors;
    }

    @Override
    @XmlElement(name = "reservedMachine")
    public List<ReservedMachineDto> getCollection()
    {
        if (collection == null)
        {
            collection = new ArrayList<ReservedMachineDto>();
        }
        return collection;
    }

    @Override
    public String getMediaType()
    {
        return MachineDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
