/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;

@XmlRootElement(name = "ucsrack")
public class UcsRackDto extends RackDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.ucsrack+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private static final long serialVersionUID = 1L;

    private Integer port;

    @Desc("Connection port to UCS")
    @NotNull
    public Integer getPort()
    {
        return port;
    }

    public void setPort(final Integer port)
    {
        this.port = port;
    }

    private String ip;

    @Desc("IP Address of the UCS server")
    @NotNull
    public String getIp()
    {
        return ip;
    }

    public void setIp(final String ip)
    {
        this.ip = ip;
    }

    private String password;

    @Desc("Password to authenticate to UCS")
    @NotNull
    public String getPassword()
    {
        return password;
    }

    public void setPassword(final String password)
    {
        this.password = password;
    }

    private String user;

    @Desc("User to log in into UCS")
    @NotNull
    public String getUser()
    {
        return user;
    }

    public void setUser(final String user)
    {
        this.user = user;
    }

    private String defaultTemplate;

    @Desc("UCS default template to use")
    public String getDefaultTemplate()
    {
        return this.defaultTemplate;
    }

    public void setDefaultTemplate(final String defaultTemplate)
    {
        this.defaultTemplate = defaultTemplate;
    }

    private Integer maxMachinesOn;

    @Desc("Maximum number of machines in power on in UCS")
    public Integer getMaxMachinesOn()
    {
        return maxMachinesOn;
    }

    public void setMaxMachinesOn(final Integer maxMachinesOn)
    {
        this.maxMachinesOn = maxMachinesOn;
    }

    @Override
    public String getMediaType()
    {
        return UcsRackDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
