/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * @author jdevesa
 */
public abstract class AbstractIpDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    private Integer id;

    private String ip;

    private String mac;

    private String name;

    private String networkName;

    @Desc("Identifier of the entity")
    @Output
    public Integer getId()
    {
        return id;
    }

    @Desc("String that represents the IP address")
    @Output
    public String getIp()
    {
        return ip;
    }

    @Desc("MAC address associated to the IP address")
    @Output
    public String getMac()
    {
        return mac;
    }

    @Desc("Lease name of the entity. It will be used by the DHCP server to identify the IP-MAC static rule")
    @Output
    public String getName()
    {
        return name;
    }

    @Desc("Name of the network which the IP belongs to")
    public String getNetworkName()
    {
        return networkName;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    public void setIp(final String ip)
    {
        this.ip = ip;
    }

    public void setMac(final String mac)
    {
        this.mac = mac;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    public void setNetworkName(final String networkName)
    {
        this.networkName = networkName;
    }

}
