/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "dhcpoption")
public class DhcpOptionDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.dhcpoption+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public DhcpOptionDto(final Integer id, final int option, final String gateway,
        final String networkAddress, final Integer mask, final String netmask)
    {
        super();
        this.id = id;
        this.option = option;
        this.gateway = gateway;
        this.networkAddress = networkAddress;
        this.mask = mask;
        this.netmask = netmask;
    }

    public DhcpOptionDto()
    {
        // TODO Auto-generated constructor stub
    }

    private Integer id;

    private int option;

    /**
     * The IP address of the gateway.
     */
    private String gateway;

    /**
     * The network that defines the address.
     */
    private String networkAddress;

    /**
     * The mask value in the integer way (/24)
     */
    private Integer mask;

    /**
     * The mask value in IP way (255.255.255.0)
     */
    private String netmask;

    @Desc("Identifier of the entity")
    @Output
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    @Desc("Gateway of the static route")
    @NotNull
    public String getGateway()
    {
        return gateway;
    }

    public void setGateway(final String gateway)
    {
        this.gateway = gateway;
    }

    @Desc("Network address of the static route")
    @NotNull
    public String getNetworkAddress()
    {
        return networkAddress;
    }

    public void setNetworkAddress(final String networkAddress)
    {
        this.networkAddress = networkAddress;
    }

    @Desc("Mask of the network of the static route in integer mode")
    @Output
    public Integer getMask()
    {
        return mask;
    }

    public void setMask(final Integer mask)
    {
        this.mask = mask;
    }

    @Desc("Mask of the network in 'xxx.xxx.xxx.xxx' format")
    @NotNull
    public String getNetmask()
    {
        return netmask;
    }

    public void setNetmask(final String netmask)
    {
        this.netmask = netmask;
    }

    @Desc("The integer value that defines the option")
    @Output
    public int getOption()
    {
        return option;
    }

    public void setOption(final int option)
    {
        this.option = option;
    }

    @Override
    public String getMediaType()
    {
        return DhcpOptionDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
