/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.rest.RESTLink;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "networkinterfacedto")
public class NetworkInterfaceDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.networkinterface+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public static final String NETWORK_SERVICE_TYPE_REL = "networkservicetype";

    private Integer id;

    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private String name;

    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    private String mac;

    public String getMac()
    {
        return mac;
    }

    public void setMac(final String mac)
    {
        this.mac = mac;
    }

    public void setNetworkServiceTypeLink(final String href)
    {
        RESTLink link = searchLink(NETWORK_SERVICE_TYPE_REL);
        if (link != null)
        {
            modifyLink(NETWORK_SERVICE_TYPE_REL, href);
        }
        else
        {
            link = new RESTLink(NETWORK_SERVICE_TYPE_REL, href);
            link.setType(NetworkServiceTypeDto.BASE_MEDIA_TYPE);
            addLink(link);
        }
    }

    public RESTLink getNetworkServiceTypeLink()
    {
        return searchLink(NETWORK_SERVICE_TYPE_REL);
    }

    @Override
    public String getMediaType()
    {
        return MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
