/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;
import com.abiquo.server.core.infrastructure.network.v20.IpPoolManagementDto20;

/**
 * The representation of {@link IpPoolManagementDto20} when we retrieve it from a VirtualMachine.
 * 
 * @author jdevesa
 */
@XmlRootElement(name = "nic")
public class NicDto extends SingleResourceTransportDto
{

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.nic+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public static final String MEDIA_TYPE_20 = BASE_MEDIA_TYPE + "; version=2.0";

    public static final String REL_PREFIX = "nic";

    private static final long serialVersionUID = 3595021795100699222L;

    private Integer id;

    private String ip;

    private String mac;

    private Integer sequence;

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    @Desc("Identifier of the entity")
    @Output
    public Integer getId()
    {
        return id;
    }

    @Desc("Ip address asociated to a NIC")
    @Output
    public String getIp()
    {
        return ip;
    }

    @Desc("MAC address of the NIC")
    public String getMac()
    {
        return mac;
    }

    @Override
    public String getMediaType()
    {
        return NicDto.MEDIA_TYPE;
    }

    @Desc("Sequence of the NIC inside its Virtual Machine")
    public Integer getSequence()
    {
        return sequence;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    public void setIp(final String ip)
    {
        this.ip = ip;
    }

    public void setMac(final String mac)
    {
        this.mac = mac;
    }

    public void setSequence(final Integer sequence)
    {
        this.sequence = sequence;
    }

}
