/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import java.io.Serializable;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.enumerator.NetworkType;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "network")
public class VLANNetworkDto extends SingleResourceTransportDto implements Serializable
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.vlan+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public static final String MEDIA_TYPE_20 = BASE_MEDIA_TYPE + "; version=" + API_VERSION_20;

    public static final String MEDIA_TYPE_22 = BASE_MEDIA_TYPE + "; version=" + API_VERSION_22;

    private Integer id;

    private String name;

    private Integer tag;

    private String gateway;

    private String address;

    private Integer mask;

    private String primaryDNS;

    private String secondaryDNS;

    private String sufixDNS;

    private Boolean defaultNetwork;

    private Boolean unmanaged;

    private NetworkType type;

    private DhcpOptionsDto dhcpOptions;

    @NotNull
    @Desc(value = "Network Address of the VLAN.")
    public String getAddress()
    {
        return address;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    @Output
    @Desc(value = "Return if it is used as Default Network. Read only.")
    public Boolean getDefaultNetwork()
    {
        return defaultNetwork;
    }

    public DhcpOptionsDto getDhcpOptions()
    {
        return dhcpOptions;
    }

    @NotNull
    @Desc(value = "Gateway of the VLAN")
    public String getGateway()
    {
        return gateway;
    }

    @Desc("Identifier of the entity")
    public Integer getId()
    {
        return id;
    }

    @NotNull
    @Desc(value = "Numerical value of the VLAN")
    public Integer getMask()
    {
        return mask;
    }

    @Override
    public String getMediaType()
    {
        return VLANNetworkDto.MEDIA_TYPE;
    }

    @NotNull
    @Desc(value = "Name of the VLAN")
    @XmlElement(defaultValue = "")
    public String getName()
    {
        return name;
    }

    @Desc(value = "Primary DNS address")
    public String getPrimaryDNS()
    {
        return primaryDNS;
    }

    @Desc(value = "Secondary DNS value")
    public String getSecondaryDNS()
    {
        return secondaryDNS;
    }

    @Desc(value = "Suffix DNS value")
    public String getSufixDNS()
    {
        return sufixDNS;
    }

    @Desc(value = "Tag of the VLAN. It will need an input value for PUBLIC, EXTERNAL and UNMANAGED networks")
    public Integer getTag()
    {
        return tag;
    }

    @Output
    @Desc(value = "Kind of network: PUBLIC, INTERNAL, EXTERNAL and UNMANAGED")
    public NetworkType getType()
    {
        return type;
    }

    @Output
    @Desc(value = "Return if the VLAN is unmanaged")
    public Boolean getUnmanaged()
    {
        return unmanaged;
    }

    public void setAddress(final String address)
    {
        this.address = address;
    }

    public void setDefaultNetwork(final Boolean defaultNetwork)
    {
        this.defaultNetwork = defaultNetwork;
    }

    public void setDhcpOptions(final DhcpOptionsDto dhcpOptions)
    {
        this.dhcpOptions = dhcpOptions;
    }

    public void setGateway(final String gateway)
    {
        this.gateway = gateway;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    public void setMask(final Integer mask)
    {
        this.mask = mask;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    public void setPrimaryDNS(final String primaryDNS)
    {
        this.primaryDNS = primaryDNS;
    }

    public void setSecondaryDNS(final String secondaryDNS)
    {
        this.secondaryDNS = secondaryDNS;
    }

    public void setSufixDNS(final String sufixDNS)
    {
        this.sufixDNS = sufixDNS;
    }

    public void setTag(final Integer tag)
    {
        this.tag = tag;
    }

    public void setType(final NetworkType type)
    {
        this.type = type;
    }

    public void setUnmanaged(final Boolean unmanaged)
    {
        this.unmanaged = unmanaged;
    }

}
