/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import java.io.Serializable;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.enumerator.VlanTagAvailabilityType;
import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * Set the transfer object for the type VlanTagAvialiabilityType
 * 
 * @author jdevesa
 */
@XmlRootElement(name = "vlanTagAvailability")
public class VlanTagAvailabilityDto extends SingleResourceTransportDto implements Serializable
{
    /**
     * Generated serial version UID.
     */
    private static final long serialVersionUID = 8354795972402115520L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.vlantagavailability+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private VlanTagAvailabilityType available;

    private String message;

    @Desc("Return if the VLAN tag is available in to be used in the Datacenter")
    @Output
    public VlanTagAvailabilityType getAvailable()
    {
        return available;
    }

    public void setAvailable(final VlanTagAvailabilityType available)
    {
        this.available = available;
    }

    @Desc("Return the reason why the tag is not available")
    @Output
    public String getMessage()
    {
        return message;
    }

    public void setMessage(final String message)
    {
        this.message = message;
    }

    @Override
    public String getMediaType()
    {
        return VlanTagAvailabilityDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
