/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.storage;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "device")
@XmlType(propOrder = {"id", "name", "storageTechnology", "managementIp", "managementPort",
"iscsiIp", "iscsiPort", "username", "password"})
public class StorageDeviceDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.storagedevice+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    @Desc("Identifier of the entity")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private int managementPort;

    @NotNull
    @Desc("Management port of the storage device, used to connect to the management API")
    public int getManagementPort()
    {
        return managementPort;
    }

    public void setManagementPort(final int managementPort)
    {
        this.managementPort = managementPort;
    }

    private String name;

    @NotNull
    @Desc("Name of the storage device")
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    private String iscsiIp;

    @NotNull
    @Desc("iSCSI IP of the storage device, used by the hypervisors to connect to the device")
    public String getIscsiIp()
    {
        return iscsiIp;
    }

    public void setIscsiIp(final String iscsiIp)
    {
        this.iscsiIp = iscsiIp;
    }

    private String storageTechnology;

    @NotNull
    @Desc("Technology type of the storage device")
    public String getStorageTechnology()
    {
        return storageTechnology;
    }

    public void setStorageTechnology(final String storageTechnology)
    {
        this.storageTechnology = storageTechnology;
    }

    private String managementIp;

    @NotNull
    @Desc("Management IP of the storage device, used to connect to the management API")
    public String getManagementIp()
    {
        return managementIp;
    }

    public void setManagementIp(final String managementIp)
    {
        this.managementIp = managementIp;
    }

    private int iscsiPort;

    @NotNull
    @Desc("iSCSI port of the storage device, used by the hypervisors to connect to the device")
    public int getIscsiPort()
    {
        return iscsiPort;
    }

    public void setIscsiPort(final int iscsiPort)
    {
        this.iscsiPort = iscsiPort;
    }

    private String username;

    public void setUsername(final String username)
    {
        this.username = username;
    }

    @Desc("Username to connect to the management API, if any")
    public String getUsername()
    {
        return username;
    }

    private String password;

    public void setPassword(final String password)
    {
        this.password = password;
    }

    @Desc("Password to connect to the management API, if any")
    public String getPassword()
    {
        return password;
    }

    @Override
    public String getMediaType()
    {
        return StorageDeviceDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
