/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.storage;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.server.core.cloud.VirtualApplianceDto;
import com.abiquo.server.core.cloud.VirtualDatacenterWithDatacenterDto;
import com.abiquo.server.core.cloud.VirtualMachineDto;

@XmlRootElement(name = "volume")
public class VolumeManagementWithVirtualMachineDto extends VolumeManagementDto
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE =
        "application/vnd.abiquo.iscsivolumewithvirtualmachine+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private VirtualMachineDto virtualMachine;

    private VirtualApplianceDto virtualAppliance;

    private VirtualDatacenterWithDatacenterDto virtualDatacenter;

    private StoragePoolWithDeviceDto storagePoolWithDevice;

    public void setVirtualMachine(final VirtualMachineDto virtualMachine)
    {
        this.virtualMachine = virtualMachine;
    }

    @Output
    @Desc("Virtual machine where the volume is attached to")
    public VirtualMachineDto getVirtualMachine()
    {
        return virtualMachine;
    }

    public void setVirtualDatacenterWithDatacenter(
        final VirtualDatacenterWithDatacenterDto virtualDatacenter)
    {
        this.virtualDatacenter = virtualDatacenter;
    }

    @Output
    @Desc("Virtual datacenter where the volume is created in, also containing the datacenter where the virtual datacenter belongs to")
    public VirtualDatacenterWithDatacenterDto getVirtualDatacenterWithDatacenter()
    {
        return virtualDatacenter;
    }

    public void setStoragePoolWithDevice(final StoragePoolWithDeviceDto storagePoolWithDevice)
    {
        this.storagePoolWithDevice = storagePoolWithDevice;
    }

    @Output
    @Desc("Storage pool where the volume is created in, also containing the device where the storage pool belongs to")
    public StoragePoolWithDeviceDto getStoragePoolWithDevice()
    {
        return storagePoolWithDevice;
    }

    public void setVirtualAppliance(final VirtualApplianceDto virtualAppliance)
    {
        this.virtualAppliance = virtualAppliance;
    }

    @Output
    @Desc("Virtual appliance of the virtual machine where the volume is attached to")
    public VirtualApplianceDto getVirtualAppliance()
    {
        return virtualAppliance;
    }

    @Override
    public String getMediaType()
    {
        return VolumeManagementWithVirtualMachineDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
