/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.statistics;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "cloudusage")
public class CloudUsageDto extends SingleResourceTransportDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.cloudusage+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    @Desc("Identifier of the virtual machine template definition")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private long virtualStorageTotal;

    @Desc("Total storage size managed to be used by Virtual Machines in Megabytes.")
    public long getVirtualStorageTotal()
    {
        return virtualStorageTotal;
    }

    public void setVirtualStorageTotal(final long virtualStorageTotal)
    {
        this.virtualStorageTotal = virtualStorageTotal;
    }

    private long virtualMemoryReserved;

    @Desc("Maximum amount of RAM reserved by all enterprises in Megabytes. ")
    public long getVirtualMemoryReserved()
    {
        return virtualMemoryReserved;
    }

    public void setVirtualMemoryReserved(final long virtualMemoryReserved)
    {
        this.virtualMemoryReserved = virtualMemoryReserved;
    }

    private long storageTotal;

    @Desc("External storage managed by Abiquo (in Megabytes) ")
    public long getStorageTotal()
    {
        return storageTotal;
    }

    public void setStorageTotal(final long storageTotal)
    {
        this.storageTotal = storageTotal;
    }

    private long virtualMemoryUsed;

    @Desc("Total amount of RAM used by Virtual Machines currently in a running state in Megabytes.")
    public long getVirtualMemoryUsed()
    {
        return virtualMemoryUsed;
    }

    public void setVirtualMemoryUsed(final long virtualMemoryUsed)
    {
        this.virtualMemoryUsed = virtualMemoryUsed;
    }

    private long virtualCpuTotal;

    @Desc("Total number of Virtual CPUs in Virtual Machines currently in a running state. ")
    public long getVirtualCpuTotal()
    {
        return virtualCpuTotal;
    }

    public void setVirtualCpuTotal(final long virtualCpuTotal)
    {
        this.virtualCpuTotal = virtualCpuTotal;
    }

    private long publicIPsUsed;

    @Desc("Total number of IPs used by virtual machines ")
    public long getPublicIPsUsed()
    {
        return publicIPsUsed;
    }

    public void setPublicIPsUsed(final long publicIPsUsed)
    {
        this.publicIPsUsed = publicIPsUsed;
    }

    private long publicIPsReserved;

    @Desc("Total number of IPs assigned to a VirtualDatacenter (Reserved) ")
    public long getPublicIPsReserved()
    {
        return publicIPsReserved;
    }

    public void setPublicIPsReserved(final long publicIPsReserved)
    {
        this.publicIPsReserved = publicIPsReserved;
    }

    private long storageUsed;

    @Desc("External storage used (attached or mounted) by any virtual machines (in Megabytes) ")
    public long getStorageUsed()
    {
        return storageUsed;
    }

    public void setStorageUsed(final long storageUsed)
    {
        this.storageUsed = storageUsed;
    }

    private long storageReserved;

    @Desc("External storage reserved by Enterprises in Datacenters (in Megabytes). ")
    public long getStorageReserved()
    {
        return storageReserved;
    }

    public void setStorageReserved(final long storageReserved)
    {
        this.storageReserved = storageReserved;
    }

    private long serversTotal;

    @Desc("Total number of Physical machines managed. ")
    public long getServersTotal()
    {
        return serversTotal;
    }

    public void setServersTotal(final long serversTotal)
    {
        this.serversTotal = serversTotal;
    }

    private long publicIPsTotal;

    @Desc("Total number of IPs defined (managed). ")
    public long getPublicIPsTotal()
    {
        return publicIPsTotal;
    }

    public void setPublicIPsTotal(final long publicIPsTotal)
    {
        this.publicIPsTotal = publicIPsTotal;
    }

    private long virtualStorageUsed;

    @Desc("Total storage size used by Virtual Machines currently in a running state in Megabytes. ")
    public long getVirtualStorageUsed()
    {
        return virtualStorageUsed;
    }

    public void setVirtualStorageUsed(final long virtualStorageUsed)
    {
        this.virtualStorageUsed = virtualStorageUsed;
    }

    private long vlanUsed;

    @Desc("Total number of VLANs in use by any datacenter managed. ")
    public long getVlanUsed()
    {
        return vlanUsed;
    }

    public void setVlanUsed(final long vlanUsed)
    {
        this.vlanUsed = vlanUsed;
    }

    private long numVdcCreated;

    @Desc("Total number of Virtual DataCenters in system")
    public long getNumVdcCreated()
    {
        return numVdcCreated;
    }

    public void setNumVdcCreated(final long numVdcCreated)
    {
        this.numVdcCreated = numVdcCreated;
    }

    private long numEnterprisesCreated;

    @Desc("Total number of enterprises in system.")
    public long getNumEnterprisesCreated()
    {
        return numEnterprisesCreated;
    }

    public void setNumEnterprisesCreated(final long numEnterprisesCreated)
    {
        this.numEnterprisesCreated = numEnterprisesCreated;
    }

    private long virtualStorageReserved;

    @Desc("Maximum storage size reserved by all enterprises for Virtual Machines in Megabytes.")
    public long getVirtualStorageReserved()
    {
        return virtualStorageReserved;
    }

    public void setVirtualStorageReserved(final long virtualStorageReserved)
    {
        this.virtualStorageReserved = virtualStorageReserved;
    }

    @Desc("Total amount of RAM managed (can be used for VMs) in Megabytes.")
    private long virtualMemoryTotal;

    public long getVirtualMemoryTotal()
    {
        return virtualMemoryTotal;
    }

    public void setVirtualMemoryTotal(final long virtualMemoryTotal)
    {
        this.virtualMemoryTotal = virtualMemoryTotal;
    }

    private long virtualCpuUsed;

    @Desc("Total number of Virtual CPUs in Virtual Machines currently in a running state. ")
    public long getVirtualCpuUsed()
    {
        return virtualCpuUsed;
    }

    public void setVirtualCpuUsed(final long virtualCpuUsed)
    {
        this.virtualCpuUsed = virtualCpuUsed;
    }

    private long virtualCpuReserved;

    @Desc("Maximum number of Virtual CPUs reserved by all enterprises. ")
    public long getVirtualCpuReserved()
    {
        return virtualCpuReserved;
    }

    public void setVirtualCpuReserved(final long virtualCpuReserved)
    {
        this.virtualCpuReserved = virtualCpuReserved;
    }

    private long virtualMachinesTotal;

    @Desc("Total number of Virtual Machines managed by Abiquo. ")
    public long getVirtualMachinesTotal()
    {
        return virtualMachinesTotal;
    }

    public void setVirtualMachinesTotal(final long virtualMachinesTotal)
    {
        this.virtualMachinesTotal = virtualMachinesTotal;
    }

    private long serversRunning;

    @Desc("Total number of Physical Machines running currently. ")
    public long getServersRunning()
    {
        return serversRunning;
    }

    public void setServersRunning(final long serversRunning)
    {
        this.serversRunning = serversRunning;
    }

    private long numUsersCreated;

    @Desc("Total number of users in system. ")
    public long getNumUsersCreated()
    {
        return numUsersCreated;
    }

    public void setNumUsersCreated(final long numUsersCreated)
    {
        this.numUsersCreated = numUsersCreated;
    }

    private long virtualMachinesRunning;

    @Desc("Total number of Virtual Machines currently in a running state.")
    public long getVirtualMachinesRunning()
    {
        return virtualMachinesRunning;
    }

    public void setVirtualMachinesRunning(final long virtualMachinesRunning)
    {
        this.virtualMachinesRunning = virtualMachinesRunning;
    }

    @Override
    public String getMediaType()
    {
        return CloudUsageDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
