/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.statistics;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "vappResources")
public class VirtualAppResourcesDto extends SingleResourceTransportDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.virtualappresources+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    @Desc("Identifier of the virtual machine template definition")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private String vdcName;

    @Desc("Name for the virtualdatacenter ")
    public String getVdcName()
    {
        return vdcName;
    }

    public void setVdcName(final String vdcName)
    {
        this.vdcName = vdcName;
    }

    private String vappName;

    @Desc("Name for this virtual appliance ")
    public String getVappName()
    {
        return vappName;
    }

    public void setVappName(final String vappName)
    {
        this.vappName = vappName;
    }

    private int volAttached;

    @Desc("Number of volumes currently attached to a virtual machine in this virtual appliance ")
    public int getVolAttached()
    {
        return volAttached;
    }

    public void setVolAttached(final int volAttached)
    {
        this.volAttached = volAttached;
    }

    private int vmCreated;

    @Desc("Number of virtual machines created in this virtual appliance ")
    public int getVmCreated()
    {
        return vmCreated;
    }

    public void setVmCreated(final int vmCreated)
    {
        this.vmCreated = vmCreated;
    }

    private int vmActive;

    @Desc("Number of virtual machines currently running in this virtual appliance ")
    public int getVmActive()
    {
        return vmActive;
    }

    public void setVmActive(final int vmActive)
    {
        this.vmActive = vmActive;
    }

    private int idEnterprise;

    public int getIdEnterprise()
    {
        return idEnterprise;
    }

    public void setIdEnterprise(final int idEnterprise)
    {
        this.idEnterprise = idEnterprise;
    }

    private int idVirtualDataCenter;

    public int getIdVirtualDataCenter()
    {
        return idVirtualDataCenter;
    }

    public void setIdVirtualDataCenter(final int idVirtualDataCenter)
    {
        this.idVirtualDataCenter = idVirtualDataCenter;
    }

    @Override
    public String getMediaType()
    {
        return VirtualAppResourcesDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
