/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.statistics;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "vdcResources")
public class VirtualDatacenterResourcesDto extends SingleResourceTransportDto
{
    public static final String BASE_MEDIA_TYPE =
        "application/vnd.abiquo.virtualdatacenterresources+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    @Desc("Identifier of the virtual machine template definition")
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private long memoryReserved;

    @Desc("Maximum amount of RAM reserved for this enterprise in this virtual datacenter in Megabytes. ")
    public long getMemoryReserved()
    {
        return memoryReserved;
    }

    public void setMemoryReserved(final long memoryReserved)
    {
        this.memoryReserved = memoryReserved;
    }

    private String vdcName;

    @Desc("virtual datacenter's name")
    public String getVdcName()
    {
        return vdcName;
    }

    public void setVdcName(final String vdcName)
    {
        this.vdcName = vdcName;
    }

    private int volCreated;

    @Desc("Number of volumes created in this virtual datacenter ")
    public int getVolCreated()
    {
        return volCreated;
    }

    public void setVolCreated(final int volCreated)
    {
        this.volCreated = volCreated;
    }

    private long vlanReserved;

    @Desc("Total maximum number of VLANs reserved for this enterprise in this virtual datacenter. (enterprise.vlanHard) ")
    public long getVlanReserved()
    {
        return vlanReserved;
    }

    public void setVlanReserved(final long vlanReserved)
    {
        this.vlanReserved = vlanReserved;
    }

    private long publicIPsUsed;

    @Desc("Total number of IPs used by virtual machines. ")
    public long getPublicIPsUsed()
    {
        return publicIPsUsed;
    }

    public void setPublicIPsUsed(final long publicIPsUsed)
    {
        this.publicIPsUsed = publicIPsUsed;
    }

    private long publicIPsReserved;

    @Desc("Total number of IPs assigned to this virtualDatacenter (Reserved). ")
    public long getPublicIPsReserved()
    {
        return publicIPsReserved;
    }

    public void setPublicIPsReserved(final long publicIPsReserved)
    {
        this.publicIPsReserved = publicIPsReserved;
    }

    private long localStorageReserved;

    @Desc("Maximum storage size reserved for this enterprise in this virtual datacenter for Virtual Machines in Megabytes. ")
    public long getLocalStorageReserved()
    {
        return localStorageReserved;
    }

    public void setLocalStorageReserved(final long localStorageReserved)
    {
        this.localStorageReserved = localStorageReserved;
    }

    private long extStorageUsed;

    @Desc("External storage used (attached or mounted) by any virtual machines (in Megabytes). ")
    public long getExtStorageUsed()
    {
        return extStorageUsed;
    }

    public void setExtStorageUsed(final long extStorageUsed)
    {
        this.extStorageUsed = extStorageUsed;
    }

    private int volAttached;

    @Desc("Number of volumes currently attached to a virtual machine in this virtual datacenter ")
    public int getVolAttached()
    {
        return volAttached;
    }

    public void setVolAttached(final int volAttached)
    {
        this.volAttached = volAttached;
    }

    private long vlanUsed;

    @Desc("Total number of VLANs in use by this virtual datacenter. ")
    public long getVlanUsed()
    {
        return vlanUsed;
    }

    public void setVlanUsed(final long vlanUsed)
    {
        this.vlanUsed = vlanUsed;
    }

    private long extStorageReserved;

    @Desc("Maximum external storage size reserved for this enterprise in this virtual datacenter in Megabytes")
    public long getExtStorageReserved()
    {
        return extStorageReserved;
    }

    public void setExtStorageReserved(final long extStorageReserved)
    {
        this.extStorageReserved = extStorageReserved;
    }

    private long localStorageUsed;

    @Desc("Total storage size used by Virtual Machines currently in a running state in Megabytes. ")
    public long getLocalStorageUsed()
    {
        return localStorageUsed;
    }

    public void setLocalStorageUsed(final long localStorageUsed)
    {
        this.localStorageUsed = localStorageUsed;
    }

    private long virtualCpuUsed;

    @Desc("Total number of Virtual CPUs in Virtual Machines currently in a running state. ")
    public long getVirtualCpuUsed()
    {
        return virtualCpuUsed;
    }

    public void setVirtualCpuUsed(final long virtualCpuUsed)
    {
        this.virtualCpuUsed = virtualCpuUsed;
    }

    @Desc("Maximum number of Virtual CPUs reserved for this enterprise in this virtual datacenter. ")
    private long virtualCpuReserved;

    public long getVirtualCpuReserved()
    {
        return virtualCpuReserved;
    }

    public void setVirtualCpuReserved(final long virtualCpuReserved)
    {
        this.virtualCpuReserved = virtualCpuReserved;
    }

    private int vmCreated;

    @Desc("Number of virtual machines created in this virtual datacenter")
    public int getVmCreated()
    {
        return vmCreated;
    }

    public void setVmCreated(final int vmCreated)
    {
        this.vmCreated = vmCreated;
    }

    private int vmActive;

    @Desc("Number of virtual machines currently running in this virtual datacenter ")
    public int getVmActive()
    {
        return vmActive;
    }

    public void setVmActive(final int vmActive)
    {
        this.vmActive = vmActive;
    }

    private long memoryUsed;

    @Desc("Total amount of RAM used by Virtual Machines currently in a running state in Megabytes. ")
    public long getMemoryUsed()
    {
        return memoryUsed;
    }

    public void setMemoryUsed(final long memoryUsed)
    {
        this.memoryUsed = memoryUsed;
    }

    private int idEnterprise;

    public int getIdEnterprise()
    {
        return idEnterprise;
    }

    public void setIdEnterprise(final int idEnterprise)
    {
        this.idEnterprise = idEnterprise;
    }

    @Override
    public String getMediaType()
    {
        return VirtualDatacenterResourcesDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
