/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.task;

import java.util.LinkedList;
import java.util.List;

import com.abiquo.model.redis.RedisEntityBase;
import com.abiquo.server.core.task.enums.TaskState;
import com.abiquo.server.core.task.enums.TaskType;

public class Task extends RedisEntityBase
{
    protected String ownerId;

    protected String taskId;

    protected String userId;

    protected TaskType type;

    protected long timestamp;

    protected TaskState state;

    protected List<Job> jobs;

    public Task()
    {
        this.jobs = new LinkedList<Job>();
        this.state = TaskState.PENDING;
    }

    @Override
    protected String getIdAsString()
    {
        return getTaskId();
    }

    public String getOwnerId()
    {
        return ownerId;
    }

    public void setOwnerId(final String ownerId)
    {
        this.ownerId = ownerId;
    }

    public String getTaskId()
    {
        return taskId;
    }

    public void setTaskId(final String taskId)
    {
        this.taskId = taskId;
    }

    public List<Job> getJobs()
    {
        return jobs;
    }

    public void setJobs(final List<Job> jobs)
    {
        this.jobs = jobs;
    }

    public String getUserId()
    {
        return userId;
    }

    public void setUserId(final String userId)
    {
        this.userId = userId;
    }

    public long getTimestamp()
    {
        return timestamp;
    }

    public void setTimestamp(final long timestamp)
    {
        this.timestamp = timestamp;
    }

    public TaskType getType()
    {
        return type;
    }

    public void setType(final TaskType type)
    {
        this.type = type;
    }

    public TaskState getState()
    {
        return state;
    }

    public void setState(final TaskState state)
    {
        this.state = state;
    }

    public boolean isAborted()
    {
        return this.getState() == TaskState.ABORTED;
    }

    public boolean isFinished()
    {
        return this.getState() == TaskState.ABORTED
            || this.getState() == TaskState.FINISHED_SUCCESSFULLY
            || this.getState() == TaskState.FINISHED_UNSUCCESSFULLY;
    }

    @Override
    public String toString()
    {
        return String.format(
            "Task id: '%s' Task type: '%s' Owner id: '%s' Owner type: '%s' State: '%s'",
            getTaskId(), getType().name(), getOwnerId(), getType().getOwnerType().name(),
            getState().name());
    }
}
