/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.task;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.doc.Desc;
import com.abiquo.model.doc.Output;
import com.abiquo.model.transport.SingleResourceTransportDto;
import com.abiquo.server.core.task.enums.TaskState;
import com.abiquo.server.core.task.enums.TaskType;

@XmlRootElement(name = "task")
public class TaskDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 3587883337292250623L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.task+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    protected String ownerId;

    protected String taskId;

    protected String userId;

    protected TaskType type;

    protected long timestamp;

    protected TaskState state;

    protected JobsDto jobs;

    public TaskDto()
    {
    }

    @Desc("Jobs collection of the task")
    @Output
    public JobsDto getJobs()
    {
        return jobs;
    }

    public void setJobs(final JobsDto jobs)
    {
        this.jobs = jobs;
    }

    @Desc("Identifier of the task owner")
    @Output
    public String getOwnerId()
    {
        return ownerId;
    }

    public void setOwnerId(final String ownerId)
    {
        this.ownerId = ownerId;
    }

    @Desc("Identifier of the task")
    @Output
    public String getTaskId()
    {
        return taskId;
    }

    public void setTaskId(final String taskId)
    {
        this.taskId = taskId;
    }

    @Desc("Identifier of the user who created the task")
    @Output
    public String getUserId()
    {
        return userId;
    }

    public void setUserId(final String userId)
    {
        this.userId = userId;
    }

    @Desc("Type of the task")
    @Output
    public TaskType getType()
    {
        return type;
    }

    public void setType(final TaskType type)
    {
        this.type = type;
    }

    @Desc("Timestamp of the last update on the task in standard UNIX timestamp")
    @Output
    public long getTimestamp()
    {
        return timestamp;
    }

    public void setTimestamp(final long timestamp)
    {
        this.timestamp = timestamp;
    }

    @Desc("Current state of the task")
    @Output
    public TaskState getState()
    {
        return state;
    }

    public void setState(final TaskState state)
    {
        this.state = state;
    }

    @Override
    public String getMediaType()
    {
        return TaskDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
